@@ -53,10 +53,10 @@ sub get_content_type_for_part {
     my $self = shift;
     my $part_name = shift;
 
-    my ($overridden) = grep { $part_name eq $_->{part_name} } @{ $self->overrides };
+    my ($overridden) = grep { "/$part_name" eq $_->{part_name} } @{ $self->overrides };
     return $overridden->{content_type} if $overridden;
 
-    my ($default) = grep { $part_name =~ /\Q.$_->{extension}\E$/ } @{ $self->defaults };
+    my ($default) = grep { "/$part_name" =~ /\Q.$_->{extension}\E$/ } @{ $self->defaults };
     return $default->{content_type} if $default;
 
     return;
@@ -76,7 +76,7 @@ Document::OOXML::ContentTypes - Part to content-type mapping for OOXML
 
 =head1 VERSION
 
-version 0.172610
+version 0.172650
 
 =head1 SYNOPSIS
 
