@@ -20,6 +20,36 @@ has document => (
     weak_ref => 1,
 );
 
+sub get_relations_part {
+    my $self = shift;
+    my $type = shift;
+    my $id   = shift;
+
+    my $rels = $self->document->get_rels_for_part($self->part_name);
+
+    return $rels;
+}
+
+sub find_referenced_part_by_id {
+    my $self = shift;
+    my $id   = shift;
+
+    my $rels = $self->get_relations_part;
+    my $data = $rels->get_part_relation_by_id($id);
+
+    return $self->document->get_part($data->{part_name});
+}
+
+sub find_referenced_part_by_type {
+    my $self = shift;
+    my $type = shift;
+
+    my $rels = $self->get_relations_part;
+    my $data = $rels->get_part_relation_by_type($type);
+
+    return $self->document->get_part($data->{part_name});
+}
+
 1;
 
 __END__
@@ -34,7 +64,7 @@ Document::OOXML::Part - Role for OOXML document parts
 
 =head1 VERSION
 
-version 0.172610
+version 0.172650
 
 =head1 SYNOPSIS
 
